
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
        Asset( "SOUND", "sound/wilson.fsb" ),
        Asset( "ANIM", "anim/beard.zip" ),
		Asset("ATLAS", "images/medtab.xml"),
        Asset( "ANIM", "anim/wisteria.zip" ),
}
--List all the items related to the character: both starting items and items that they only can craft (such as Walani's surfboard)
local prefabs = {
	"flowerhat",
	"silkbandage",
	"ointment",
	"wounddressing",
	"herbalbandage",
	"cutlichen",
}

--The character's starting items
local start_inv = {
	"flowerhat",
}

--First part of the eating healing boost (Wisteria's perk)
local function oneat(inst, food)
	inst.components.health:DoDelta((food.components.edible:GetHealth(inst)/2), nil, food.prefab)
end

--In this section goes everything you see and custom craftable items/recipes (such as Walani's surfboard). Example: local surfboard_recipe = Recipe("surfboard_item", {Ingredient("boards", 1), Ingredient("seashell", 2)}, RECIPETABS.NAUTICAL, TECH.NONE,  RECIPE_GAME_TYPE.SHIPWRECKED)
local fn = function(inst)
	
	--Which sounds this character will play
	inst.soundsname = "wendy"

	--Minimap icon
	inst.MiniMapEntity:SetIcon( "wisteria.tex" )
	
	--Stats (some are dependant on the configuration we set, as you can see)
	inst.components.health:SetMaxHealth(TUNING.WISTERIA_HEALTH)
	inst.components.hunger:SetMax(150)
	inst.components.sanity:SetMax(TUNING.WISTERIA_SANITY)
	
	--Damage multiplier. It uses a different formula if you are using shipwrecked, check my other file "wisteria_sw" in the same folder you found this. The standard is TUNING.WILSON_DAMAGE_MULT
    inst.components.combat.damagemultiplier = TUNING.WISTERIA_DAMAGE_MULT
	
	--Hunger rate if you want your character to get hungry faster or slower. This is a default value.
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	--Movement speed if you want your character to be faster or slower. This is a default value.
	inst.components.locomotor.walkspeed = 4
	inst.components.locomotor.runspeed = 6

	--Second part of the eating healing boost
	inst.components.eater:SetOnEatFn(oneat)
	
	--Faster picking plants (Wisteria's perk)
	local handle = inst.sg.sg.actionhandlers[ACTIONS.PICK]
	handle.deststate = function(inst) return "doshortaction" end

	--We will now create a separate crafting tab for all the medical items since dumping them all in the survival tab wouldn't be professional and cause unnecessary crowding in an important vanilla tab.
		local medtab = {str = STRINGS.TABS.MEDICAL, sort=999, icon = "medtab.tex", icon_atlas = "images/medtab.xml"}
		inst.components.builder:AddRecipeTab(medtab)
	
	--This is a passage i would have loved to skip but if we don't, we'll end up having recipes where the ingredients don't have any picture. It's a purely cosmetic thing but why would we ignore it?
	local Isilkbandage = Ingredient("silkbandage", 1)
	local Iointment = Ingredient("ointment", 1)
	local Icutlichen = Ingredient("cutlichen", 3)
	Isilkbandage.atlas = "images/inventoryimages/silkbandage.xml"
	Iointment.atlas = "images/inventoryimages/ointment.xml"
	Icutlichen.atlas = "images/inventoryimages/cutlichen.xml"
	
	--I will introduce here all the crafting recipes that are unique to Wisteria. Also, i relocated here the vanilla healing salve and honey poultice so as to have all healing items in one place.
	
		local silkbandage = Recipe("silkbandage",{Ingredient("silk", 2)}, medtab ,TECH.SCIENCE_ONE)
		silkbandage.atlas = "images/inventoryimages/silkbandage.xml" 
		
		local ointment = Recipe("ointment",{Ingredient("petals", 3), Ingredient("butterflywings", 1)}, medtab ,TECH.SCIENCE_ONE)
		ointment.atlas = "images/inventoryimages/ointment.xml"
		
		local Rhealingsalve = Recipe("healingsalve",{Ingredient("ash", 2), Ingredient("rocks", 1), Ingredient("spidergland", 1)}, medtab, TECH.SCIENCE_ONE)
		
		local wounddressing = Recipe("wounddressing",{Isilkbandage, Iointment}, medtab , TECH.SCIENCE_TWO)
		wounddressing.atlas = "images/inventoryimages/wounddressing.xml"
		
		local Rbandage = Recipe("bandage", {Ingredient("papyrus", 1), Ingredient("honey", 2)}, medtab, TECH.SCIENCE_TWO)
		
		local herbalbandage = Recipe("herbalbandage", {Isilkbandage, Icutlichen}, medtab, TECH.SCIENCE_TWO)
		herbalbandage.atlas = "images/inventoryimages/herbalbandage.xml"
end

return MakePlayerCharacter("wisteria", prefabs, assets, fn, start_inv)
